/*
 * analyzer_slow.c
 *                   Simple slow analyzer for nova development
 *
 *              version 1.02  30-SEP-1992 M. Nomachi (KEK)
 *
 * usage: analyzer_slow [name [priority [sleep]]]
 */
#include <signal.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include "nova.h"

#define DEFAULT_NAME     "/tmp/nova"
#define DEFAULT_PRI      40
#define DEFAULT_SLEEP    10

main(argc, argv) int argc; char *argv[]; {
  struct NOVAD *nd, *nova_copen();
  char name[NV_MAXNAME + 1];
  int *data, length, priority;
  int status, loop, i, sleep_time;
  
  /* Read options */
  strcpy(name, (argc > 1) ? argv[1] : DEFAULT_NAME);
  priority   = (argc > 2) ? atoi(argv[2]) : DEFAULT_PRI;
  sleep_time = (argc > 3) ? atoi(argv[3]) : DEFAULT_SLEEP;
  
  /* open NOVA */
  if ((int)(nd = nova_open(name, priority,0)) == -1) {
    printf("analyzer: cannot open %s", name);
    exit(1);
  }
  
  for(loop=1;1;loop++) {
    /*
     * Get one buffer and return to free buffer pool.
     * Successive buffers may passed over this process.
     */
    alarm(10);
    printf(" The following buffer will be returned to free buffer\n");
    status = nova_get(nd, &data, &length);
    switch (status) {
    case 0:   /* nomal */
      printf("analyzer: loop=%d  length=%d byte", loop, length);
      for(i = 0; i < 3; i++) printf(" %8X", data[i]);
      printf("\n");
      if ((sleep_time >0) && (sleep_time<60)) sleep(sleep_time);
      status = nova_put(nd, data, 0, 0);
      break;
    case 1:   /* Interrupted */
      printf("analyzer: interrupted!\n");
      break;
    default:  /* error */
      printf("analyzer: error! %d\n",status);
      break;
    }
    if (status < 0)  break;


    /*
     * Get one buffer and forward to next process.
     * Successive buffers may wait the processing.
     */
    alarm(10);
    printf(" The following buffer will be forward to next process\n");
    status = nova_resume(nd,1);
    status = nova_get(nd, &data, &length);
    switch (status) {
    case 0:   /* nomal */
      printf("analyzer: loop=%d  length=%d byte", loop, length);
      for(i = 0; i < 3; i++) printf(" %8X", data[i]);
      printf("\n");
      if ((sleep_time >0) && (sleep_time<60)) sleep(sleep_time);
      status = nova_pause(nd);
      break;
    case 1:   /* Interrupted */
      printf("analyzer: interrupted!\n");
      break;
    default:  /* error */
      printf("analyzer: error! %d\n",status);
      break;
    }
    if (status < 0)  break;
  
    /*
     * Successive buffers may pass this processing.
     */
    printf(" The successive buffers may pass this process\n");
    if ((sleep_time >0) && (sleep_time<60)) sleep(sleep_time);

  }
  printf("analyzer: nomal end.\n");
  nova_close(nd);
}

